@@ -1,4 +1,6 @@
 class ConsumerToken:
+    """Represents a consumer token pair"""
+
     def __init__(self, key, secret):
         self.key = key
         self.secret = secret
@@ -10,6 +12,10 @@ class RequestToken:
         self.token_secret = token_secret
 
 
+class AccessToken(RequestToken):
+    """Represents a access token pair"""
+
+
 class Meter:
     def __init__(self, serialNumber, type, measurementType, location, **kwargs):
         """Represents a meter"""
@@ -32,6 +38,7 @@ class Location:
         self.street_number = streetNumber
         self.country = country
 
+
 class Reading:
     def __init__(self, time, values):
         """Represents a reading"""
